@@ -8,11 +8,10 @@ import narwhals as nw
 from tests.utils import DUCKDB_VERSION, Constructor, assert_equal_data
 
 
-@pytest.mark.parametrize("col_expr", [nw.col("a"), "a"])
-def test_sumh(constructor: Constructor, col_expr: Any) -> None:
+def test_sumh(constructor: Constructor) -> None:
     data = {"a": [1, 3, 2], "b": [4, 4, 6], "z": [7.0, 8.0, 9.0]}
     df = nw.from_native(constructor(data))
-    result = df.with_columns(horizontal_sum=nw.sum_horizontal(col_expr, nw.col("b")))
+    result = df.with_columns(horizontal_sum=nw.sum_horizontal("a", nw.col("b")))
     expected = {
         "a": [1, 3, 2],
         "b": [4, 4, 6],
