@@ -174,10 +174,14 @@ def test_when_then_otherwise_multi_output(constructor: Constructor) -> None:
 def test_when_then_otherwise_aggregate_select(
     condition: nw.Expr,
     then: nw.Expr | int,
-    otherwise: nw.Expr | int,
+    otherwise: nw.Expr | int | None,
     expected: list[int],
     constructor: Constructor,
+    request: pytest.FixtureRequest,
 ) -> None:
+    if "cudf" in str(constructor) and otherwise is None:
+        reason = "cudf does not support mixed types"
+        request.applymarker(pytest.mark.xfail(reason=reason))
     df = nw.from_native(constructor({"a": [1, 2, 3], "b": [4, 5, 6]}))
     result = df.select(a_when=nw.when(condition).then(then).otherwise(otherwise))
     assert_equal_data(result, {"a_when": expected})
@@ -201,12 +205,17 @@ def test_when_then_otherwise_aggregate_select(
 def test_when_then_otherwise_aggregate_with_columns(
     condition: nw.Expr,
     then: nw.Expr | int,
-    otherwise: nw.Expr | int,
+    otherwise: nw.Expr | int | None,
     expected: list[int],
     constructor: Constructor,
+    request: pytest.FixtureRequest,
 ) -> None:
     if "duckdb" in str(constructor) and DUCKDB_VERSION < (1, 3):
         pytest.skip()
+    if "cudf" in str(constructor) and otherwise is None:
+        reason = "cudf does not support mixed types"
+        request.applymarker(pytest.mark.xfail(reason=reason))
+
     df = nw.from_native(constructor({"a": [1, 2, 3], "b": [4, 5, 6]}))
     expr = nw.when(condition).then(then).otherwise(otherwise)
     result = df.with_columns(a_when=expr)
