@@ -25,12 +25,12 @@ def test_item(
 @pytest.mark.parametrize(
     ("row", "column", "err_msg"),
     [
-        (0, None, re.escape("cannot call `.item()` with only one of `row` or `column`")),
-        (None, 0, re.escape("cannot call `.item()` with only one of `row` or `column`")),
+        (0, None, "cannot call `.item()` with only one of `row` or `column`"),
+        (None, 0, "cannot call `.item()` with only one of `row` or `column`"),
         (
             None,
             None,
-            re.escape("can only call `.item()` if the dataframe is of shape (1, 1)"),
+            'can only call `.item()` without "row" or "column" values if the DataFrame has a single element; shape=(3, 3)',
         ),
     ],
 )
@@ -41,5 +41,5 @@ def test_item_value_error(
     err_msg: str,
 ) -> None:
     data = {"a": [1, 3, 2], "b": [4, 4, 6], "z": [7.0, 8.0, 9.0]}
-    with pytest.raises(ValueError, match=err_msg):
+    with pytest.raises(ValueError, match=re.escape(err_msg)):
         nw.from_native(constructor_eager(data), eager_only=True).item(row, column)
