@@ -3,8 +3,7 @@ from __future__ import annotations
 from typing import TYPE_CHECKING
 
 import narwhals as nw
-from tests.utils import ConstructorEager
-from tests.utils import is_windows
+from tests.utils import ConstructorEager, is_windows
 
 if TYPE_CHECKING:
     import pytest
