@@ -6,7 +6,7 @@ from typing import TYPE_CHECKING, Any
 import pytest
 
 import narwhals as nw
-import narwhals.stable.v1 as nw_v1
+import narwhals.stable.v2 as nw_v2
 
 if TYPE_CHECKING:
     from collections.abc import Iterator
@@ -19,30 +19,26 @@ def remove_docstring_examples(doc: str) -> str:
 
 
 def test_stable_api_completeness() -> None:
-    v_1_api = nw_v1.__all__
+    v2_api = nw_v2.__all__
     main_namespace_api = nw.__all__
-    extra = set(v_1_api).difference(main_namespace_api)
+    extra = set(v2_api).difference(main_namespace_api)
     assert not extra
-    missing = set(main_namespace_api).difference(v_1_api).difference({"stable"})
+    missing = set(main_namespace_api).difference(v2_api).difference({"stable"})
     assert not missing
 
 
 def test_stable_api_docstrings() -> None:
     main_namespace_api = nw.__all__
     for item in main_namespace_api:
+        if item in {"from_dict"}:
+            # We keep `native_namespace` around in the main namespace
+            # until at least hierarchical forecast make a release
+            continue
         if (doc := getdoc(getattr(nw, item))) is None:
             continue
-        if item in {"from_native", "narwhalify", "get_level"}:
-            # `eager_or_interchange` param was removed from main namespace,
-            # but is still present in v1 docstring.
-            continue
-        if item == "Enum":
-            # In v1 this was Polars-only, after that pandas ordered categoricals
-            # started to be mapped to it too, so the docstring changed.
-            continue
-        v1_doc = getdoc(getattr(nw_v1, item))
-        assert v1_doc is not None
-        assert remove_docstring_examples(v1_doc) == remove_docstring_examples(doc), item
+        v2_doc = getdoc(getattr(nw_v2, item))
+        assert v2_doc is not None
+        assert remove_docstring_examples(v2_doc) == remove_docstring_examples(doc), item
 
 
 def _iter_api_method_docs(obj: Any, *exclude: str) -> Iterator[tuple[str, str]]:
@@ -59,35 +55,38 @@ def test_dataframe_docstrings() -> None:
     pytest.importorskip("polars")
     import polars as pl
 
-    df_v1 = nw_v1.from_native(pl.DataFrame())
+    df_v2 = nw_v2.from_native(pl.DataFrame())
     df = nw.from_native(pl.DataFrame())
     for method_name, doc in _iter_api_method_docs(df):
-        doc_v1 = getdoc(getattr(df_v1, method_name))
-        assert doc_v1
-        assert remove_docstring_examples(doc_v1) == remove_docstring_examples(doc)
+        doc_v2 = getdoc(getattr(df_v2, method_name))
+        assert doc_v2
+        assert remove_docstring_examples(doc_v2) == remove_docstring_examples(doc)
 
 
 def test_lazyframe_docstrings() -> None:
     pytest.importorskip("polars")
     import polars as pl
 
-    ldf_v1 = nw_v1.from_native(pl.LazyFrame())
+    ldf_v2 = nw_v2.from_native(pl.LazyFrame())
     ldf = nw.from_native(pl.LazyFrame())
     performance_warning = {"schema", "columns"}
     deprecated = {"tail", "gather_every"}
     for method_name, doc in _iter_api_method_docs(ldf, *performance_warning, *deprecated):
-        doc_v1 = getdoc(getattr(ldf_v1, method_name))
-        assert doc_v1
-        assert remove_docstring_examples(doc_v1) == remove_docstring_examples(doc)
+        doc_v2 = getdoc(getattr(ldf_v2, method_name))
+        assert doc_v2
+        assert remove_docstring_examples(doc_v2) == remove_docstring_examples(doc)
 
 
 def test_series_docstrings() -> None:
     pytest.importorskip("polars")
     import polars as pl
 
-    ser_v1 = nw_v1.from_native(pl.Series(), series_only=True)
+    ser_v2 = nw_v2.from_native(pl.Series(), series_only=True)
     ser = nw.from_native(pl.Series(), series_only=True)
     for method_name, doc in _iter_api_method_docs(ser):
-        doc_v1 = getdoc(getattr(ser_v1, method_name))
-        assert doc_v1
-        assert remove_docstring_examples(doc_v1) == remove_docstring_examples(doc)
+        if method_name in "hist":
+            # This is still very unstable in Polars so we don't have it in stable.v2 yet.
+            continue
+        doc_v2 = getdoc(getattr(ser_v2, method_name))
+        assert doc_v2
+        assert remove_docstring_examples(doc_v2) == remove_docstring_examples(doc)
