@@ -28,7 +28,7 @@ def test_to_native(
     constructor_eager: ConstructorEager, method: str, *, pass_through: bool, context: Any
 ) -> None:
     if method == "to_numpy":
-        pytest.importorskip("mumpy")
+        pytest.importorskip("numpy")
     df = nw.from_native(constructor_eager({"a": [1, 2, 3]}))
 
     with context:
